==> mgu74bv2.db_2.0.2.tar.gz: mgu74bv2.db/man/mgu74bv2_dbconn.Rd <==
\name{mgu74bv2_dbconn}

\alias{mgu74bv2_dbconn}
\alias{mgu74bv2_dbfile}
\alias{mgu74bv2_dbschema}
\alias{mgu74bv2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mgu74bv2_dbconn()
  mgu74bv2_dbfile()
  mgu74bv2_dbschema(file="", show.indices=FALSE)
  mgu74bv2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mgu74bv2_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{mgu74bv2_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{mgu74bv2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mgu74bv2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mgu74bv2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mgu74bv2_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{mgu74bv2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mgu74bv2_dbschema}: none (invisible \code{NULL}).

  \code{mgu74bv2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mgu74bv2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mgu74bv2_dbconn() was created with:
  dbConnect(SQLite(), dbname=mgu74bv2_dbfile(), cache_size=64000, synchronous=0)

  mgu74bv2_dbschema()

  mgu74bv2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> mgu74bv2.db_2.4.5.tar.gz: mgu74bv2.db/man/mgu74bv2_dbconn.Rd <==

\name{mgu74bv2_dbconn}

\alias{mgu74bv2_dbconn}
\alias{mgu74bv2_dbfile}
\alias{mgu74bv2_dbschema}
\alias{mgu74bv2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mgu74bv2_dbconn()
  mgu74bv2_dbfile()
  mgu74bv2_dbschema(file="", show.indices=FALSE)
  mgu74bv2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mgu74bv2_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{mgu74bv2_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{mgu74bv2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mgu74bv2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mgu74bv2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mgu74bv2_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{mgu74bv2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mgu74bv2_dbschema}: none (invisible \code{NULL}).

  \code{mgu74bv2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mgu74bv2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mgu74bv2_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=mgu74bv2_dbfile(), cache_size=64000,
  synchronous=0)

  mgu74bv2_dbschema()

  mgu74bv2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
